#
# spec file for package beets
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           beets
Version:        1.4.6
Release:        bp153.1.19
Summary:        Music tagger and library organizer
License:        MIT
Group:          Productivity/Multimedia/Sound/Players
Url:            http://beets.io/
Source:         https://github.com/beetbox/beets/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         0001-Fixed-failing-test-where.patch
# PATCH-FIX-UPSTREAM fix_test_command_line_option_relative_to_working_dir.diff alarrosa@suse.de - Fixes one of the tests to run successfully
Patch1:         fix_test_command_line_option_relative_to_working_dir.diff
# PATCH-FIX-UPSTREAM fix-pathlib-requirement.diff alarrosa@suse.de - Don't require pathlib for tests in python >= 3.4.0
Patch2:         fix-pathlib-requirement.diff
BuildRequires:  python3-PyYAML
BuildRequires:  python3-Unidecode
BuildRequires:  python3-devel
BuildRequires:  python3-jellyfish
BuildRequires:  python3-munkres
BuildRequires:  python3-musicbrainzngs >= 0.4
BuildRequires:  python3-mutagen >= 1.33
BuildRequires:  python3-setuptools
BuildRequires:  python3-six >= 1.9
# test requirements
BuildRequires:  python3-Flask
BuildRequires:  python3-beautifulsoup4
BuildRequires:  python3-discogs-client
BuildRequires:  python3-mock
%if 0%{?suse_version} <= 1320
BuildRequires:  python3-pathlib
%endif
BuildRequires:  python3-pylast
BuildRequires:  python3-python-mpd2 >= 0.4.2
BuildRequires:  python3-pyxdg
BuildRequires:  python3-rarfile
BuildRequires:  python3-responses
BuildRequires:  python3-testsuite
Requires:       python3-PyYAML
Requires:       python3-Unidecode
Requires:       python3-jellyfish
Requires:       python3-munkres
Requires:       python3-musicbrainzngs >= 0.4
Requires:       python3-mutagen >= 1.33
Requires:       python3-six >= 1.9
Recommends:     python3-pyacoustid
Recommends:     python3-flask
Recommends:     python3-flask-cors
Recommends:     python3-discogs-client >= 2.1.0
Recommends:     python3-pyxdg
Recommends:     python3-requests
Recommends:     python3-dbus-python
Recommends:     python3-rarfile
Recommends:     python3-requests-oauthlib >= 0.6.1
Recommends:     python3-python-mpd2
Recommends:     python3-pylast
Recommends:     python3-requests
Recommends:     ffmpeg
Suggests:       flac
Suggests:       mp3val
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Beets is a media library management system for obsessive-compulsive music
geeks.

The purpose of beets is to get a music collection right once and for all.
It catalogs the collection, automatically improving its metadata as it goes.
It then provides a bouquet of tools for manipulating and accessing the music.

beets is designed as a library, has a number of plugins which
support these actions:

- Fetch or calculate all the metadata that could possibly be needed:
  album art, lyrics, genres, tempos, ReplayGain levels, or acoustic
  fingerprints.
- Get metadata from MusicBrainz, Discogs, and Beatport, or guess
  metadata using songs' filenames or their acoustic fingerprints.
- Transcode audio to any format.
- Check your library for duplicate tracks and albums or for albums that
  are missing tracks.
- Clean up crufty tags left behind by other tools.
- Embed and extract album art from files' metadata.
- Browse the music library graphically through a Web browser and play it in any
  browser that supports HTML5 Audio.
- Analyze music files' metadata from the command line.
- Listen to your library with a music player that speaks the MPD protocol
  and works with a variety of interfaces.

Writing additional plugins for beets is possible using Python.

%prep
%setup -q -n beets-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{_bindir}/beet
%{python3_sitelib}/*

%changelog
* Thu Jan  4 2018 alarrosa@suse.com
- Update to 1.4.6:
  * The highlight of this release is "album merging," an often requested
    option in the importer to add new tracks to an existing album you already
    have in your library. This way, you no longer need to resort to removing
    the partial album from your library, combining the files manually, and
    importing again.
  * Here are the larger new features in this release:
  * When the importer finds duplicate albums, you can now merge all the
    tracks—old and new—together and try importing them as a single,
    combined album.
  * lyrics: The plugin can now produce reStructuredText files for beautiful,
    readable books of lyrics.
  * A new from_scratch configuration option makes the importer remove old
    metadata before applying new metadata. This new feature complements the
    zero and scrub plugins but is slightly different: beets clears out all
    the old tags it knows about and only keeps the new data it gets from
    the remote metadata source.
  * There are also somewhat littler, but still great, new features:
  * convert: A new no_convert option lets you skip transcoding items matching
    a query. Instead, the files are just copied as-is.
  * fetchart: A new quiet switch that only prints out messages when album art
    is missing.
  * mbcollection: You can configure a custom MusicBrainz collection via the
    new collection configuration option.
  * mbcollection: The collection update command can now remove albums from
    collections that are longer in the beets library.
  * fetchart: The clearart command now asks for confirmation before touching
    your files.
  * mpdstats: The plugin now correctly updates song statistics when MPD
    switches from a song to a stream and when it plays the same song
    multiple times consecutively.
  * acousticbrainz: The plugin can now be configured to write only a specific
    list of tags.
  * Lots of bug fixes.
  * The full changelog can be read at
    https://github.com/beetbox/beets/blob/master/docs/changelog.rst
- Fixed rpm package group
* Tue Aug  8 2017 jengelh@inai.de
- Improve write style of description
* Mon Aug  7 2017 alarrosa@suse.com
- Remove %%check since it makes random failures that are fixed just
  by retriggering a package build.
* Thu Jun 29 2017 alarrosa@suse.com
- Update to 1.4.5:
  * You can now set fields to certain values during import, using either
    a --set field=value command-line flag or a new set_fields configuration
    option under the importer section.
  * Date queries can now include times, so you can filter your music down
    to the second.
  * Date queries can also be relative. You can say added:-1w.. to match
    music added in the last week, for example.
  * A new gmusic lets you interact with your Google Play Music library.
  * replaygain: We now keep R128 data in separate tags from classic
    ReplayGain data for formats that need it (namely, Ogg Opus). A new r128
    configuration option enables this behavior for specific formats.
  * The move command gained a new --export flag, which copies files to an
    external location without changing their paths in the library database.
  * There are also some bug fixes:
  * lastgenre: Fix a crash when using the prefer_specific and canonical
    options together.
  * web: Fix a crash on Windows under Python 2 when serving non-ASCII
    filenames.
  * metasync: Fix a crash in the Amarok backend when filenames contain
    quotes.
  * More informative error messages are displayed when the file format is not
    recognized.
- Update to 1.4.4:
  * Added support for DSF files, once a future version of Mutagen is released
    that supports them.
  * A new hardlink config option instructs the importer to create hard links
    on filesystems that support them.
  * A new kodiupdate lets you keep your Kodi library in sync with beets.
  * A new bell configuration option under the import section enables
    a terminal bell when input is required.
  * A new field, composer_sort, is now supported and fetched from MusicBrainz.
  * The MusicBrainz backend and discogs now both provide a new attribute
    called track_alt that stores more nuanced, possibly non-numeric track
    index data. For example, some vinyl or tape media will report the side of
    the record using a letter instead of a number in that field.
  * web: Added a new endpoint, /item/path/foo, which will return the item info
    for the file at the given path, or 404.
  * web: Added a new config option, include_paths, which will cause paths
    to be included in item API responses if set to true.
  * The %%aunique template function for aunique now takes a third argument that
    specifies which brackets to use around the disambiguator value. The
    argument can be any two characters that represent the left and right
    brackets. It defaults to [] and can also be blank to turn off bracketing.
  * Added a --move or -m option to the importer so that the files can be moved
    to the library instead of being copied or added "in place."
  * badfiles: Added a --verbose or -v option. Results are now displayed only
    for corrupted files by default and for all the files when the verbose
    option is set.
  * embedart: The explicit embedart command now asks for confirmation before
    embedding art into music files.
  * You can now run beets by typing python -m beets.
  * smartplaylist: Different playlist specifications that generate
    identically-named playlist files no longer conflict; instead, the
    resulting lists of tracks are concatenated.
  * missing: A new mode lets you see missing albums from artists you have in
    your library.
  * web : Add new reverse_proxy config option to allow serving the web plugins
    under a reverse proxy.
  * Importing a release with multiple release events now selects the event
    based on your preferred countries.
  * play: A new -y or --yes parameter lets you skip the warning message
    if you enqueue more items than the warning threshold usually allows.
  * Fix a bug where commands which forked subprocesses would sometimes
    prevent further inputs. This bug mainly affected convert.
  * There are also quite a few fixes:
  * In the replace configuration option, we now replace a leading hyphen (-)
    with an underscore.
  * absubmit: We no longer filter audio files for specific formats---we will
    attempt the submission process for all formats.
  * mpdupdate: Fix Python 3 compatibility.
  * replaygain: Fix Python 3 compatibility in the bs1770gain backend.
  * bpd: Report playback times as integers.
  * mpdstats: Fix Python 3 compatibility. The plugin also now requires
    version 0.4.2 or later of the python-mpd2 library.
  * mpdstats: Improve handling of MPD status queries.
  * badfiles: Fix Python 3 compatibility.
  * Fix some cases where album-level ReplayGain/SoundCheck metadata would be
    written to files incorrectly.
  * badfiles: The command no longer bails out if the validator command is
    not found or exits with an error.
  * lyrics: The Google search backend no longer crashes when the server
    responds with an error.
  * discogs: You can now authenticate with Discogs using a personal access
    token.
  * Fix Python 3 compatibility when extracting rar archives in the importer.
  * duplicates: Fix Python 3 compatibility when using the copy and move
    options.
  * mbsubmit: The tracks are now sorted properly.
  * thumbnails: Fix a string-related crash on Python 3.
  * beatport: More than just 10 songs are now fetched per album.
  * On Python 3, the terminal_encoding setting is respected again for output
    and printing will no longer crash on systems configured with a limited
    encoding.
  * convert: The default configuration uses FFmpeg's built-in AAC codec
    instead of faac.
  * Fix the importer's detection of multi-disc albums when other
    subdirectories are present.
  * Invalid date queries now print an error message instead of being
    silently ignored.
  * When the SQLite database stops being accessible, we now print a friendly
    error message.
  * web: Avoid a crash when sending binary data, such as Chromaprint
    fingerprints, in music attributes.
  * Fix a hang when parsing templates that end in newlines.
  * Fix a crash when reading non-ASCII characters in configuration files on
    Windows under Python 3.
  * Some backends were removed from two metadata plugins because of bitrot:
  * lyrics: The Lyrics.com backend has been removed. (It stopped working
    because of changes to the site's URL structure.)
  * fetchart: The documentation no longer recommends iTunes Store artwork
    lookup because the unmaintained python-itunes is broken.
- Dropped patches already included upstream:
  * 0001-Add-missing-unittest-suite-declaration.patch
  * 0001-Fix-2381-mpdupdate-on-Python-3.patch
  * 0001-Fix-2382-replaygain-backend-parsing-on-Python-3.patch
  * 0001-Fixed-failing-test-because-mocked-data-was-missing-p.patch
  * 0001-Fixed-failing-test-where-track-number-was-missing-fr.patch
  * 0001-Remove-dependencies-from-convert_stub.py.patch
  * 0001-badfiles-Better-logging-and-error-handling.patch
  * 0001-mpdstats-Fix-Python-3-compatibility.patch
  * 0002-badfiles-Python3-compatibility.patch
  * 0001-Run-python2-or-python3.patch
- Rebase fix_test_command_line_option_relative_to_working_dir.diff
- Changed url to use the github release link.
- BuildRequires python3-python-mpd2 >= 0.4.2
* Mon Apr 10 2017 alarrosa@suse.com
- Only BuildRequire python3-pathlib when not in Tumbleweed, since
  the pathlib module was included in the standard library in python 3.4
* Thu Jan 19 2017 alarrosa@suse.com
- Initial release.
- Add 0001-Add-missing-unittest-suite-declaration.patch,
  0001-Fix-2381-mpdupdate-on-Python-3.patch,
  0001-Fix-2382-replaygain-backend-parsing-on-Python-3.patch,
  0001-Fixed-failing-test-because-mocked-data-was-missing-p.patch,
  0001-Fixed-failing-test-where.patch,
  0001-Fixed-failing-test-where-track-number-was-missing-fr.patch,
  0001-Remove-dependencies-from-convert_stub.py.patch,
  0001-Run-python2-or-python3.patch,
  0001-mpdstats-Fix-Python-3-compatibility.patch,
  0001-badfiles-Better-logging-and-error-handling.patch and
  0002-badfiles-Python3-compatibility.patch from upstream to fix
  most failing tests and python3 issues.
- Add fix_test_command_line_option_relative_to_working_dir.diff
  to fix test_ui.py making all tests run successfully.
